@@ -1,9 +1,9 @@
+//requires
+// * gmp.h
+// * darray.h
 #ifndef MNT_H
 #define MNT_H
 
-#include "darray.h"
-#include "curve.h"
-
 struct cm_info_s {
     mpz_t q; //curve defined over F_q
     mpz_t n; //has order n (= q - t + 1) in F_q (and r^2 in F_q^k)
