@@ -1,7 +1,7 @@
 #include <stdio.h>
 #include <string.h>
 
-char *getline(void)
+char *pbc_getline(void)
 {
     char s[1024];
     fgets(s, 1024, stdin);
